@@ -24,6 +24,7 @@
 #include "thememodel.h"
 
 #include <QDir>
+#include <QRegularExpression>
 
 #include "crtheme.h"
 #include "cfgfile.h"
@@ -64,7 +65,7 @@ QVariant XCursorThemeModel::headerData(int section, Qt::Orientation orientation,
         }
     }
     // Numbered vertical header labels
-    return QString(section);
+    return QString(QChar(section));
 }
 
 QVariant XCursorThemeModel::data(const QModelIndex &index, int role) const
@@ -136,14 +137,14 @@ const QStringList XCursorThemeModel::searchPaths()
         while (j.hasNext()) if (j.next() == path) j.remove();
     }
     // Expand all occurrences of ~/ to the home dir
-    mBaseDirs.replaceInStrings(QRegExp(QStringLiteral("^~\\/")), QDir::home().path() + QLatin1Char('/'));
+    mBaseDirs.replaceInStrings(QRegularExpression(QStringLiteral("^~\\/")), QDir::home().path() + QLatin1Char('/'));
     return mBaseDirs;
 }
 
 bool XCursorThemeModel::hasTheme(const QString &name) const
 {
     const uint hash = qHash(name);
-    for (const XCursorThemeData *theme : qAsConst(mList)) if (theme->hash() == hash) return true;
+    for (const XCursorThemeData *theme : std::as_const(mList)) if (theme->hash() == hash) return true;
     return false;
 }
 
