@@ -6,42 +6,42 @@
     <message>
         <location filename="../selectwnd.ui" line="14"/>
         <source>LXQt Mouse Theme Configuration</source>
-        <translation>LXQt-cursorthema-instellingen</translation>
+        <translation>LXQt-cursorthemainstellingen</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="46"/>
+        <location filename="../selectwnd.ui" line="20"/>
         <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
-        <translation>Kies het cursorthema dat u wilt gebruiken (ga met de muis naar de voorvertoning om uit te proberen). &lt;b&gt;Herstart de LXQt-sessie om de wijziging toe te passen&lt;/b&gt;:</translation>
+        <translation>Kies het cursorthema dat u wilt gebruiken. Houd de muis op de voorvertoning bovenaan om het thema in kwestie uit te proberen. &lt;b&gt;Meld u na het wijzigen af en weer aan&lt;/b&gt;:</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="23"/>
+        <location filename="../selectwnd.ui" line="104"/>
         <source>&amp;Install New Theme...</source>
         <translation>Thema &amp;installeren…</translation>
     </message>
     <message>
         <location filename="../selectwnd.ui" line="72"/>
         <source>LXQt session needs restart to view this change.</source>
-        <translation>Herstart de LXQt-sessie om de wijziging toe te passen.</translation>
+        <translation>Meld u af en weer aan om de wijziging toe te passen.</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="91"/>
+        <location filename="../selectwnd.ui" line="111"/>
         <source>&amp;Remove Theme</source>
         <translation>Thema ve&amp;rwijderen</translation>
     </message>
     <message>
-        <location filename="../selectwnd.ui" line="111"/>
+        <location filename="../selectwnd.ui" line="65"/>
         <source>Size</source>
         <translation>Grootte</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="230"/>
+        <location filename="../selectwnd.cpp" line="229"/>
         <source>XCurTheme error</source>
         <translation>XcurTheme-fout</translation>
     </message>
     <message>
-        <location filename="../selectwnd.cpp" line="231"/>
+        <location filename="../selectwnd.cpp" line="230"/>
         <source>You can&apos;t remove active theme!</source>
-        <translation>U kunt het actieve thema niet verwijderen!</translation>
+        <translation>U kunt het in gebruik zijnde thema niet verwijderen!</translation>
     </message>
 </context>
 <context>
@@ -54,7 +54,7 @@
     <message>
         <location filename="../warninglabel.ui" line="44"/>
         <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
-        <translation>Er is geen cursorthema aangetroffen. In plaats daarvan zal het standaardthema van X11 worden gebruikt. LXQt heeft de volgende mappen doorzocht:</translation>
+        <translation>Er is geen cursorthema aangetroffen. Het standaardthema van X11 zal daarom worden gebruikt. LXQt heeft de volgende mappen doorzocht:</translation>
     </message>
     <message>
         <location filename="../warninglabel.ui" line="54"/>
@@ -65,12 +65,12 @@
 <context>
     <name>XCursorThemeModel</name>
     <message>
-        <location filename="../thememodel.cpp" line="61"/>
+        <location filename="../thememodel.cpp" line="62"/>
         <source>Name</source>
         <translation>Naam</translation>
     </message>
     <message>
-        <location filename="../thememodel.cpp" line="62"/>
+        <location filename="../thememodel.cpp" line="63"/>
         <source>Description</source>
         <translation>Beschrijving</translation>
     </message>
