@@ -54,6 +54,7 @@ StyleConfig::StyleConfig(LXQt::Settings* settings, QSettings* qtSettings, QWidge
 
     connect(ui->qtComboBox, QOverload<int>::of(&QComboBox::activated), this, &StyleConfig::settingsChanged);
     connect(ui->toolButtonStyle, QOverload<int>::of(&QComboBox::activated), this, &StyleConfig::settingsChanged);
+    connect(ui->toolBarIconSize, QOverload<int>::of(&QComboBox::activated), this, &StyleConfig::settingsChanged);
     connect(ui->singleClickActivate, &QAbstractButton::clicked, this, &StyleConfig::settingsChanged);
 
     connect(ui->winColorLabel, &ColorLabel::colorChanged, this, &StyleConfig::settingsChanged);
@@ -64,6 +65,8 @@ StyleConfig::StyleConfig(LXQt::Settings* settings, QSettings* qtSettings, QWidge
     connect(ui->highlightedTextColorLabel, &ColorLabel::colorChanged, this, &StyleConfig::settingsChanged);
     connect(ui->linkColorLabel, &ColorLabel::colorChanged, this, &StyleConfig::settingsChanged);
     connect(ui->linkVisitedColorLabel, &ColorLabel::colorChanged, this, &StyleConfig::settingsChanged);
+    connect(ui->tooltipColorLabel, &ColorLabel::colorChanged, this, &StyleConfig::settingsChanged);
+    connect(ui->tooltipTextColorLabel, &ColorLabel::colorChanged, this, &StyleConfig::settingsChanged);
 
     connect(ui->defaultPaletteBtn, &QAbstractButton::clicked, [this] {
         QColor winColor(239, 239, 239);
@@ -77,6 +80,9 @@ StyleConfig::StyleConfig(LXQt::Settings* settings, QSettings* qtSettings, QWidge
         ui->highlightedTextColorLabel->setColor(defaultPalette.color(QPalette::Active,QPalette::HighlightedText), true);
         ui->linkColorLabel->setColor(defaultPalette.color(QPalette::Active,QPalette::Link), true);
         ui->linkVisitedColorLabel->setColor(defaultPalette.color(QPalette::Active,QPalette::LinkVisited), true);
+        // tooltips use the Inactive color group
+        ui->tooltipColorLabel->setColor(defaultPalette.color(QPalette::Inactive,QPalette::ToolTipBase), true);
+        ui->tooltipTextColorLabel->setColor(defaultPalette.color(QPalette::Inactive,QPalette::ToolTipText), true);
     });
 
     connect(ui->savePaletteBtn, &QAbstractButton::clicked, this, &StyleConfig::savePalette);
@@ -104,6 +110,33 @@ void StyleConfig::initControls()
       val = Qt::ToolButtonTextBesideIcon;
     ui->toolButtonStyle->setCurrentIndex(val);
 
+    // toolbar icon size
+    int index = mSettings->value(QLatin1String("tool_bar_icon_size")).toInt();
+    if (index < 16) // consult the active Qt style
+        index = style()->pixelMetric(QStyle::PM_ToolBarIconSize);
+    switch (index)
+    {
+        case 16:
+            index = 0;
+            break;
+        case 22:
+            index = 1;
+            break;
+        case 24:
+            index = 2;
+            break;
+        case 32:
+            index = 3;
+            break;
+        case 48:
+            index = 4;
+            break;
+        default:
+            index = 2;
+            break;
+    }
+    ui->toolBarIconSize->setCurrentIndex(index);
+
     // activate item views with single click
     ui->singleClickActivate->setChecked( mSettings->value(QStringLiteral("single_click_activate"), false).toBool());
 
@@ -160,6 +193,17 @@ void StyleConfig::initControls()
         color = QGuiApplication::palette().color(QPalette::Active,QPalette::LinkVisited);
     ui->linkVisitedColorLabel->setColor(color);
 
+    // tooltips use the Inactive color group
+    color = QColor::fromString(mSettings->value(QStringLiteral("tooltip_base_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Inactive,QPalette::ToolTipBase);
+    ui->tooltipColorLabel->setColor(color);
+
+    color = QColor::fromString(mSettings->value(QStringLiteral("tooltip_text_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Inactive,QPalette::ToolTipText);
+    ui->tooltipTextColorLabel->setColor(color);
+
     mSettings->endGroup();
 
     update();
@@ -217,6 +261,16 @@ void StyleConfig::applyStyle()
     if (color != oldColor)
         mSettings->setValue(QStringLiteral("link_visited_color"), color.name());
 
+    color = ui->tooltipColorLabel->getColor();
+    oldColor = QColor::fromString(mSettings->value(QStringLiteral("tooltip_base_color")).toString());
+    if (color != oldColor)
+        mSettings->setValue(QStringLiteral("tooltip_base_color"), color.name());
+
+    color = ui->tooltipTextColorLabel->getColor();
+    oldColor = QColor::fromString(mSettings->value(QStringLiteral("tooltip_text_color")).toString());
+    if (color != oldColor)
+        mSettings->setValue(QStringLiteral("tooltip_text_color"), color.name());
+
     mSettings->endGroup();
 
     // single click setting
@@ -237,6 +291,37 @@ void StyleConfig::applyStyle()
         mSettings->sync();
         emit updateOtherSettings();
     }
+
+    // toolbar icon size
+    index = ui->toolBarIconSize->currentIndex();
+    switch (index)
+    {
+        case 0:
+            index = 16;
+            break;
+        case 1:
+            index = 22;
+            break;
+        case 2:
+            index = 24;
+            break;
+        case 3:
+            index = 32;
+            break;
+        case 4:
+            index = 48;
+            break;
+        default:
+            index = 24;
+            break;
+    }
+    if(index != mSettings->value(QLatin1String("tool_bar_icon_size")).toInt())
+    {
+        mSettings->setValue(QStringLiteral("tool_bar_icon_size"), index);
+        // TODO: Do we want to apply it to GTK somehow?
+        /*mSettings->sync();
+        emit updateOtherSettings();*/
+    }
 }
 
 void StyleConfig::savePalette()
@@ -285,6 +370,12 @@ void StyleConfig::savePalette()
     color = ui->linkVisitedColorLabel->getColor();
     settings.setValue(QStringLiteral("link_visited_color"), color.name());
 
+    color = ui->tooltipColorLabel->getColor();
+    settings.setValue(QStringLiteral("tooltip_base_color"), color.name());
+
+    color = ui->tooltipTextColorLabel->getColor();
+    settings.setValue(QStringLiteral("tooltip_text_color"), color.name());
+
     settings.endGroup();
 }
 
@@ -394,54 +485,70 @@ void StyleConfig::loadPalette()
     dialog.setQuestion(tr("Do you really want to remove selected palette(s)?\nRoot palettes will remain intact if existing."));
 
     if (dialog.exec() == QDialog::Accepted)
-    { // set color labels
-        auto paletteFile = dialog.currentPalette();
-        if (paletteFile.isEmpty())
-            return;
-        QSettings settings(paletteFile, QSettings::IniFormat);
-        settings.beginGroup(QStringLiteral("Palette"));
-
-        QColor color;
-        color = QColor::fromString(settings.value(QStringLiteral("window_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::Window);
-        ui->winColorLabel->setColor(color, true);
-
-        color = QColor::fromString(settings.value(QStringLiteral("base_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::Base);
-        ui->baseColorLabel->setColor(color, true);
-
-        color = QColor::fromString(settings.value(QStringLiteral("highlight_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::Highlight);
-        ui->highlightColorLabel->setColor(color, true);
-
-        color = QColor::fromString(settings.value(QStringLiteral("window_text_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::WindowText);
-        ui->windowTextColorLabel->setColor(color, true);
-
-        color = QColor::fromString(settings.value(QStringLiteral("text_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::Text);
-        ui->viewTextColorLabel->setColor(color, true);
-
-        color = QColor::fromString(settings.value(QStringLiteral("highlighted_text_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::HighlightedText);
-        ui->highlightedTextColorLabel->setColor(color, true);
-
-        color = QColor::fromString(settings.value(QStringLiteral("link_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::Link);
-        ui->linkColorLabel->setColor(color, true);
-
-        color = QColor::fromString(settings.value(QStringLiteral("link_visited_color")).toString());
-        if (!color.isValid())
-            color = QGuiApplication::palette().color(QPalette::Active,QPalette::LinkVisited);
-        ui->linkVisitedColorLabel->setColor(color, true);
-
-        settings.endGroup();
+    {
+        loadPaletteFile(dialog.currentPalette());
     }
 }
+
+void StyleConfig::loadPaletteFile(const QString& paletteFile)
+{ // set color labels
+    if (paletteFile.isEmpty())
+        return;
+
+    QSettings settings(paletteFile, QSettings::IniFormat);
+    settings.beginGroup(QStringLiteral("Palette"));
+
+    QColor color;
+    color = QColor::fromString(settings.value(QStringLiteral("window_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::Window);
+    ui->winColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("base_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::Base);
+    ui->baseColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("highlight_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::Highlight);
+    ui->highlightColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("window_text_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::WindowText);
+    ui->windowTextColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("text_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::Text);
+    ui->viewTextColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("highlighted_text_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::HighlightedText);
+    ui->highlightedTextColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("link_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::Link);
+    ui->linkColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("link_visited_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Active,QPalette::LinkVisited);
+    ui->linkVisitedColorLabel->setColor(color, true);
+
+    // tooltips use the Inactive color group
+    color = QColor::fromString(settings.value(QStringLiteral("tooltip_base_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Inactive,QPalette::ToolTipBase);
+    ui->tooltipColorLabel->setColor(color, true);
+
+    color = QColor::fromString(settings.value(QStringLiteral("tooltip_text_color")).toString());
+    if (!color.isValid())
+        color = QGuiApplication::palette().color(QPalette::Inactive,QPalette::ToolTipText);
+    ui->tooltipTextColorLabel->setColor(color, true);
+
+    settings.endGroup();
+}
