@@ -5,7 +5,7 @@
     <name>ColorLabel</name>
     <message>
         <location filename="../colorLabel.cpp" line="37"/>
-        <source>Click to change color.</source>
+        <source>Click to change color</source>
         <translation>色を選択するにはクリックします。</translation>
     </message>
     <message>
@@ -175,16 +175,16 @@
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="93"/>
-        <source>GTK 3 Theme</source>
-        <translation>GTK3 テーマ</translation>
+        <source>GTK 3 Theme:</source>
+        <translation>GTK3 テーマ:</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="77"/>
-        <source>GTK 2 Theme</source>
-        <translation>GTK2 テーマ</translation>
+        <source>GTK 2 Theme:</source>
+        <translation>GTK2 テーマ:</translation>
     </message>
     <message>
-        <location filename="../gtkconfig.ui" line="103"/>
+        <location filename="../gtkconfig.ui" line="105"/>
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
@@ -459,8 +459,8 @@ Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply the
     </message>
     <message>
         <location filename="../styleconfig.ui" line="51"/>
-        <source>Qt Style</source>
-        <translation>Qt スタイル</translation>
+        <source>Qt Style:</source>
+        <translation>Qt スタイル:</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="330"/>
