@@ -5,8 +5,8 @@
     <name>ColorLabel</name>
     <message>
         <location filename="../colorLabel.cpp" line="37"/>
-        <source>Click to change color.</source>
-        <translation>Koona wo okukyusa langi.</translation>
+        <source>Click to change color</source>
+        <translation>Koona wo okukyusa langi</translation>
     </message>
     <message>
         <location filename="../colorLabel.cpp" line="61"/>
@@ -176,13 +176,13 @@
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="93"/>
-        <source>GTK 3 Theme</source>
-        <translation>Lulyo lw&apos;endabika ya GTK 3</translation>
+        <source>GTK 3 Theme:</source>
+        <translation>Lulyo lw&apos;endabika ya GTK 3:</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="77"/>
-        <source>GTK 2 Theme</source>
-        <translation>Lulyo lw&apos;endabika ya GTK 2</translation>
+        <source>GTK 2 Theme:</source>
+        <translation>Lulyo lw&apos;endabika ya GTK 2:</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="103"/>
@@ -463,8 +463,8 @@ ebikozesa GTK okukwata mangu endabika zino.</translation>
     </message>
     <message>
         <location filename="../styleconfig.ui" line="51"/>
-        <source>Qt Style</source>
-        <translation>Musono gw&apos;ebikozesa Qt</translation>
+        <source>Qt Style:</source>
+        <translation>Musono gw&apos;ebikozesa Qt:</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="330"/>
