@@ -5,8 +5,8 @@
     <name>ColorLabel</name>
     <message>
         <location filename="../colorLabel.cpp" line="37"/>
-        <source>Click to change color.</source>
-        <translation>Nhấp để thay đổi màu.</translation>
+        <source>Click to change color</source>
+        <translation>Nhấp để thay đổi màu</translation>
     </message>
     <message>
         <location filename="../colorLabel.cpp" line="61"/>
@@ -175,16 +175,16 @@
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="93"/>
-        <source>GTK 3 Theme</source>
-        <translation>Chủ đề GTK 3</translation>
+        <source>GTK 3 Theme:</source>
+        <translation>Chủ đề GTK 3:</translation>
     </message>
     <message>
         <location filename="../gtkconfig.ui" line="77"/>
-        <source>GTK 2 Theme</source>
-        <translation>Chủ đề GTK 2</translation>
+        <source>GTK 2 Theme:</source>
+        <translation>Chủ đề GTK 2:</translation>
     </message>
     <message>
-        <location filename="../gtkconfig.ui" line="103"/>
+        <location filename="../gtkconfig.ui" line="105"/>
         <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.
 
 Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
@@ -459,8 +459,8 @@ Hãy chắc là &apos;xsettingsd&apos; được cài đặt để giúp các ứ
     </message>
     <message>
         <location filename="../styleconfig.ui" line="51"/>
-        <source>Qt Style</source>
-        <translation>Phong cách Qt</translation>
+        <source>Qt Style:</source>
+        <translation>Phong cách Qt:</translation>
     </message>
     <message>
         <location filename="../styleconfig.cpp" line="330"/>
