@@ -29,12 +29,12 @@ class OutputWidget: public QWidget
 Q_OBJECT
 public:
     OutputWidget(MonitorInfo monitor, QWidget *parent);
+    ~OutputWidget();
 
 signals:
     void changed(MonitorInfo info);
 
 public slots:
-    void backlightChanged(int value);
     void brightnessChanged(int value);
     void setRevertedValues(const MonitorInfo & monitor);
 protected:
