@@ -27,7 +27,6 @@
 #include <QStringBuilder>
 
 // FIXME: how to support XCB or Wayland?
-#include <QX11Info>
 #include <X11/Xlib.h>
 #include <X11/XKBlib.h>
 
@@ -52,6 +51,9 @@ KeyboardConfig::KeyboardConfig(LXQt::Settings* _settings, QSettings* _qtSettings
   loadSettings();
   initControls();
 
+  connect(ui.keyboardDelay, &QAbstractSlider::valueChanged, ui.label_delay, QOverload<int>::of(&QLabel::setNum));
+  connect(ui.keyboardInterval, &QAbstractSlider::valueChanged, ui.label_interval, QOverload<int>::of(&QLabel::setNum));
+
   // set_range_stops(ui.keyboardDelay, 10);
   connect(ui.keyboardDelay, &QAbstractSlider::valueChanged, this, &KeyboardConfig::settingsChanged);
   // set_range_stops(ui.keyboardInterval, 10);
@@ -86,12 +88,15 @@ void KeyboardConfig::applyConfig()
 {
   bool acceptSetting = false;
 
+    auto x11NativeInterface = qGuiApp->nativeInterface<QNativeInterface::QX11Application>();
+    Display* dpy = x11NativeInterface->display();
+
   /* apply keyboard values */
   if(delay != ui.keyboardDelay->value() || interval != ui.keyboardInterval->value())
   {
     delay = ui.keyboardDelay->value();
     interval = ui.keyboardInterval->value();
-    XkbSetAutoRepeatRate(QX11Info::display(), XkbUseCoreKbd, delay, interval);
+    XkbSetAutoRepeatRate(dpy, XkbUseCoreKbd, delay, interval);
     acceptSetting = true;
   }
 
@@ -100,7 +105,7 @@ void KeyboardConfig::applyConfig()
     beep = ui.keyboardBeep->isChecked();
     XKeyboardControl values;
     values.bell_percent = beep ? -1 : 0;
-    XChangeKeyboardControl(QX11Info::display(), KBBellPercent, &values);
+    XChangeKeyboardControl(dpy, KBBellPercent, &values);
     acceptSetting = true;
   }
 
@@ -154,7 +159,11 @@ void KeyboardConfig::reset() {
   beep = oldBeep;
   numlock = oldNumlock;
   flashTime = oldFlashTime;
-  XkbSetAutoRepeatRate(QX11Info::display(), XkbUseCoreKbd, delay, interval);
+  if(auto x11NativeInterface = qGuiApp->nativeInterface<QNativeInterface::QX11Application>()) {
+    if(Display* dpy = x11NativeInterface->display()) {
+      XkbSetAutoRepeatRate(dpy, XkbUseCoreKbd, delay, interval);
+    }
+  }
   /* FIXME: beep? */
 
   initControls();
