@@ -22,6 +22,7 @@
 
 #include <KScreen/GetConfigOperation>
 #include <KScreen/SetConfigOperation>
+#include <LXQt/Notification>
 #include "monitor.h"
 
 class LoadSettings : public QObject
@@ -29,20 +30,22 @@ class LoadSettings : public QObject
     Q_OBJECT
 
 public:
-    LoadSettings(QObject *parent = 0);
-
-private Q_SLOTS:
-    void loadConfiguration(KScreen::ConfigPtr config);
+    LoadSettings(QObject *parent = nullptr);
+    
+    void applyBestSettings();
 
 private:
+    QList<MonitorSettings> loadCurrentConfiguration();
+    QList<MonitorSettings> loadConfiguration(QString scope);
+    LXQt::Notification *mNotification;
 
-    // Configutarions
+    // Configurations
     KScreen::ConfigPtr mConfig;
 };
 
 /*! Apply settings.
  */
-void applySettings(KScreen::ConfigPtr config, QList<MonitorSettings> monitors);
+bool applySettings(KScreen::ConfigPtr config, QList<MonitorSettings> monitors);
 
 
 #endif // __LOADSETTINGS_H__
